import { RequestFn, WalletEventListener, WatchAssetParameters, ChainId as ChainId$1, Permission, TypedData, StarknetWindowObject } from '@starknet-io/types-js';
import { Account, AccountInterface, ProviderOptions, ProviderInterface, CairoVersion, ArraySignatureType, Call as Call$1 } from 'starknet';
import { WalletWithFeatures, Wallet, WalletAccount } from '@wallet-standard/base';
import { StandardConnectFeature, StandardDisconnectFeature, StandardEventsFeature } from '@wallet-standard/features';

interface MulticallElement {
    readonly target: string;
    readonly entrypoint: string;
    readonly calldata: string[];
}
interface MulticallProps {
    calls: MulticallElement[];
}
interface EVMFunction {
    readonly type: 'function';
    readonly name: string;
    readonly inputs: ReadonlyArray<ParameterDescription>;
    readonly outputs?: ReadonlyArray<ParameterDescription>;
    readonly stateMutability?: 'pure' | 'view' | 'nonpayable' | 'payable';
}
interface ParameterDescription {
    readonly name: string;
    readonly type: string;
    readonly internalType?: string;
    readonly components?: ReadonlyArray<ParameterDescription>;
}
type Encodable = EncodablePrimitive | EncodableTuple | EncodableArray;
type EncodablePrimitive = Uint8Array | string | boolean | bigint;
interface EncodableTuple {
    [x: string]: Encodable;
}
interface EncodableArray extends ReadonlyArray<Encodable> {
}
interface Call {
    entry_point: string;
    contract_address: string;
    calldata: string[];
}
interface CallObject {
    contractAddress: string;
    entrypoint: string;
    calldata: string[];
}
interface EthereumProvider {
    request(): Promise<any>;
    id: string;
    name: string;
    icon: string;
    version: string;
    on: <T extends string>(eventName: T, listener: (...args: unknown[]) => void) => void;
    off: <T extends string>(eventName: T, listener: (...args: unknown[]) => void) => void;
}
declare const ETHEREUM_CHAIN_PREFIX = "eip155:";
declare const STARKNET_CHAIN_PREFIX = "starknet:";
type ChainId = `0x${string}`;
type EthereumChain = `${typeof ETHEREUM_CHAIN_PREFIX}${string}`;
type StarknetChain = `${typeof STARKNET_CHAIN_PREFIX}${ChainId}`;
/**
 * PRIMITIVES
 */
/**
 * An Ethereum address, represented as 40 hex digits.
 * @pattern ^0x[a-fA-F0-9]{40}$
 */
type ETH_ADDRESS = string;
/**
 * A transaction hash, represented as a 32-byte hex string.
 * @pattern ^0x[a-fA-F0-9]{64}$
 */
type TXN_HASH = string;
/**
 * A block hash, represented as a 32-byte hex string.
 * @pattern ^0x[a-fA-F0-9]{64}$
 */
type BLOCK_HASH = string;
/**
 * A block number, represented as a positive integer.
 */
type BLOCK_NUMBER = string | number | 'latest' | 'finalized' | 'pending';
/**
 * A nonce, represented as a hex string of at most 16 hex digits.
 * @pattern ^0x(0|[a-fA-F1-9]{1}[a-fA-F0-9]{0,15})$
 */
type NONCE = string;
/**
 * Gas value, represented as a hex string.
 * @pattern ^0x(0|[a-fA-F1-9]{1}[a-fA-F0-9]{0,15})$
 */
type GAS = string;
/**
 * A storage key, represented as a 32-byte hex string.
 * @pattern ^0x[a-fA-F0-9]{64}$
 */
type STORAGE_KEY = string;
/**
 * A 256-bit integer, represented as a hex string of length at most 64.
 * @pattern ^0x(0|[a-fA-F1-9]{1}[a-fA-F0-9]{0,63})$
 */
type UINT256 = string;
/**
 * A 128-bit integer, represented as a hex string of length at most 32.
 * @pattern ^0x(0|[a-fA-F1-9]{1}[a-fA-F0-9]{0,31})$
 */
type UINT128 = string;
/**
 * A signature, represented as an array of two 32-byte hex strings (r, s).
 */
type SIGNATURE = [string, string];
/**
 * A chain ID, represented as a hex string.
 * @pattern ^0x[a-fA-F0-9]{1,64}$
 */
type CHAIN_ID = string;
/**
 * Transaction Status Enum
 */
declare enum TX_STATUS {
    /** The transaction has been created but not yet broadcasted. */
    CREATED = "CREATED",
    /** The transaction has been received by the network but not yet included in a block. */
    PENDING = "PENDING",
    /** The transaction is included in a block but is not yet finalized. */
    INCLUDED = "INCLUDED",
    /** The transaction has been successfully executed and confirmed on-chain. */
    SUCCESS = "SUCCESS",
    /** The transaction was included in a block but reverted due to an error. */
    FAILED = "FAILED",
    /** The transaction was dropped from the mempool and will not be processed. */
    DROPPED = "DROPPED",
    /** The transaction was replaced by another transaction with the same nonce but a higher gas price. */
    REPLACED = "REPLACED"
}
/**
 * Call that modifies state and consumes gas.
 */
type STATE_CHANGING_CALL = 'CALL' | 'CREATE' | 'DELEGATECALL' | 'STATICCALL';
/**
 * Call that does not modify state and is free to execute.
 */
type VIEW_CALL = 'STATICCALL';
/**
 * Calls that occur internally between smart contracts.
 */
type INTERNAL_CALL = 'CALL' | 'DELEGATECALL' | 'STATICCALL';
/**
 * Low-level Ethereum calls.
 */
type LOW_LEVEL_CALL = 'CALLCODE' | 'SELFDESTRUCT';
/**
 * ETH-specific calls.
 */
type ETH_CALL = 'TRANSFER' | 'SEND';
type CALL_TYPE = STATE_CHANGING_CALL | VIEW_CALL | INTERNAL_CALL | LOW_LEVEL_CALL | ETH_CALL;
/**
 * Block Status Enum
 */
declare enum BLOCK_STATUS {
    /** The block has been proposed but not yet finalized. */
    PENDING = "PENDING",
    /** The block has been included in the chain but is not yet finalized. */
    INCLUDED = "INCLUDED",
    /** The block has been confirmed and is unlikely to be reverted. */
    CONFIRMED = "CONFIRMED",
    /** The block has been finalized and cannot be changed. */
    FINALIZED = "FINALIZED",
    /** The block was reorged out of the chain and is no longer valid. */
    REORGED = "REORGED",
    /** The block was invalidated due to a protocol or consensus issue. */
    INVALID = "INVALID"
}
/**
 * Block Tag of 'latest' or 'pending' block.
 */
type BLOCK_TAG = 'latest' | 'pending';
/**
 * Transaction Type Enum
 */
declare enum TX_TYPE {
    /** A standard ETH transfer from one EOA to another. */
    TRANSFER = "TRANSFER",
    /** A transaction that deploys a new smart contract. */
    CONTRACT_CREATION = "CONTRACT_CREATION",
    /** A transaction calling a smart contract function, possibly modifying state. */
    CONTRACT_CALL = "CONTRACT_CALL",
    /** A transaction that delegates execution to another contract while maintaining the caller's context. */
    DELEGATECALL = "DELEGATECALL",
    /** A read-only transaction that does not modify state (gas-free). */
    STATICCALL = "STATICCALL",
    /** A transaction using the EIP-1559 fee structure (Base Fee + Priority Fee). */
    EIP1559 = "EIP1559",
    /** A legacy transaction using a gas price instead of the EIP-1559 model. */
    LEGACY = "LEGACY",
    /** A transaction that cancels or replaces a pending transaction with a higher gas price. */
    CANCEL = "CANCEL",
    /** A transaction that self-destructs a contract and transfers remaining ETH. */
    SELFDESTRUCT = "SELFDESTRUCT"
}
/**
 * Ethereum Transaction Type (Based on provided data)
 */
type TX = {
    /** List of addresses involved in the transaction and their access lists (if any). */
    accessList: Array<{
        address: ETH_ADDRESS;
        storageKeys: string[];
    }>;
    /** Block hash where the transaction was included. */
    blockHash: BLOCK_HASH;
    /** Block number in which the transaction was included (hex string). */
    blockNumber: BLOCK_NUMBER;
    /** Chain ID (for preventing replay attacks). */
    chainId: CHAIN_ID;
    /** Sender's Ethereum address. */
    from: ETH_ADDRESS;
    /** Gas limit for the transaction (hex string). */
    gas: string;
    /** Gas price (used for legacy transactions). */
    gasPrice: string;
    /** Transaction hash (unique identifier). */
    hash: TXN_HASH;
    /** Input data for the transaction (used in contract calls). */
    input: string;
    /** Maximum fee per gas (used for EIP-1559 transactions). */
    maxFeePerGas: string;
    /** Maximum priority fee per gas (used for EIP-1559 transactions). */
    maxPriorityFeePerGas: string;
    /** Nonce of the transaction (unique per sender). */
    nonce: string;
    /** Transaction signature component 'r'. */
    r: string;
    /** Transaction signature component 's'. */
    s: string;
    /** Transaction recipient address (or `null` for contract creation). */
    to: ETH_ADDRESS | null;
    /** Index of the transaction in the block. */
    transactionIndex: number;
    /** Type of transaction (EIP-1559 or legacy). */
    type: string;
    /** Transaction signature component 'v'. */
    v: string;
    /** Value of Ether sent in the transaction (in Wei, hex string). */
    value: string;
    /** Parity for the transaction's signature (optional, included in some cases). */
    yParity: string;
};
/**
 * Ethereum Transaction Receipt Type
 */
type TX_RECEIPT = {
    /** Transaction hash (32 bytes). */
    transactionHash: TXN_HASH;
    /** Index of the transaction within the block. */
    transactionIndex: number;
    /** Block number in which the transaction was included. */
    blockNumber: BLOCK_NUMBER;
    /** Block hash in which the transaction was included. */
    blockHash: BLOCK_HASH;
    /** The address that deployed the contract (if applicable). */
    contractAddress: ETH_ADDRESS | null;
    /** Gas used by the transaction execution. */
    gasUsed: string;
    /** Cumulative gas used by the transaction and all preceding ones in the block. */
    cumulativeGasUsed: string;
    /** Effective gas price (EIP-1559) or gas price (legacy). */
    effectiveGasPrice: string;
    /** Logs generated by the transaction. */
    logs: LOG_ENTRY[];
    /** Logs bloom filter for indexing events. */
    logsBloom: string;
    /** Transaction status: `1` for success, `0` for failure. */
    status: TX_STATUS;
    /** Type of transaction (EIP-1559, Legacy, etc.). */
    type: TX_TYPE;
    /** The address of the sender of the transaction. */
    from: ETH_ADDRESS;
    /** The address of the recipient or `null` if contract creation. */
    to: ETH_ADDRESS | null;
};
/**
 * Ethereum Log Entry Type
 */
type LOG_ENTRY = {
    /** Address that emitted the log. */
    address: ETH_ADDRESS;
    /** List of indexed topics (max 4). */
    topics: string[];
    /** Non-indexed data field. */
    data: string;
    /** Block number in which the log was included. */
    blockNumber: BLOCK_NUMBER;
    /** Transaction hash associated with the log. */
    transactionHash: TXN_HASH;
    /** Index of the log within the transaction. */
    logIndex: number;
    /** Index of the log within the block. */
    blockIndex: number;
};
/**
 * Ethereum Block Type
 */
type BLOCK = {
    /** Block number (or `null` if it's a pending block). */
    number: BLOCK_NUMBER | null;
    /** Block hash (or `null` if it's a pending block). */
    hash: BLOCK_HASH | null;
    /** Hash of the parent block. */
    parentHash: BLOCK_HASH;
    /** Hash of the state root after executing this block. */
    stateRoot: string;
    /** Hash of the transactions root. */
    transactionsRoot: string;
    /** Hash of the receipts root. */
    receiptsRoot: string;
    /** Bloom filter for logs in the block. */
    logsBloom: string;
    /** Address of the block miner. */
    miner: ETH_ADDRESS;
    /** Difficulty of the block. */
    difficulty: string;
    /** Total difficulty up to this block. */
    totalDifficulty: string;
    /** Extra data included in the block. */
    extraData: string;
    /** Size of the block in bytes. */
    size: string;
    /** Gas limit for the block. */
    gasLimit: string;
    /** Total gas used in this block. */
    gasUsed: string;
    /** Base fee per gas (EIP-1559) or `null` for pre-London blocks. */
    baseFeePerGas?: string | null;
    /** Timestamp when the block was mined. */
    timestamp: number;
    /** List of transaction hashes included in the block. */
    transactions: TXN_HASH[];
    /** List of uncle block hashes (empty for modern Ethereum blocks). */
    uncles: BLOCK_HASH[];
    /** Mix hash used in proof-of-work (pre-Merge). */
    mixHash?: string;
    /** Proof-of-work nonce (pre-Merge). */
    nonce?: string;
};
/**
 * Ethereum Block Receipts Type
 */
type BLOCK_RECEIPTS = {
    /** The block number in which these receipts belong. */
    blockNumber: BLOCK_NUMBER;
    /** The block hash in which these receipts belong. */
    blockHash: BLOCK_HASH;
    /** List of transaction receipts in the block. */
    receipts: TX_RECEIPT[];
};
/**
 * Ethereum Transaction Request Type
 */
type TX_REQUEST = {
    /** The transaction type (optional). */
    type?: null | number;
    /** The target address of the transaction (optional). */
    to?: null | ETH_ADDRESS;
    /** The sender address of the transaction (optional). */
    from?: null | ETH_ADDRESS;
    /** The nonce of the transaction (optional). */
    nonce?: null | number;
    /** The gas limit for the transaction (optional). */
    gasLimit?: null | string;
    /** The gas price for legacy transactions (optional). */
    gasPrice?: null | string;
    /** The max priority fee to pay per gas (EIP-1559) (optional). */
    maxPriorityFeePerGas?: null | string;
    /** The max total fee to pay per gas (EIP-1559) (optional). */
    maxFeePerGas?: null | string;
    /** The transaction data (optional). */
    data?: null | string;
    /** The value of the transaction in wei (optional). */
    value?: null | string;
    /** The chain ID for the transaction (optional). */
    chainId?: null | string;
    /** The access list for EIP-2930 transactions (optional). */
    accessList?: null | Array<{
        address: ETH_ADDRESS;
        storageKeys: string[];
    }>;
    /** Custom data for network-specific values (optional). */
    customData?: any;
    /** Block tag for call or estimateGas (optional). */
    blockTag?: string;
    /** Whether CCIP-read should be enabled (optional). */
    enableCcipRead?: boolean;
    /** Blob versioned hashes for EIP-4844 transactions (optional). */
    blobVersionedHashes?: null | Array<string>;
    /** The maximum fee per blob gas for EIP-4844 (optional). */
    maxFeePerBlobGas?: null | string;
};

type index_BLOCK = BLOCK;
type index_BLOCK_HASH = BLOCK_HASH;
type index_BLOCK_NUMBER = BLOCK_NUMBER;
type index_BLOCK_RECEIPTS = BLOCK_RECEIPTS;
type index_BLOCK_STATUS = BLOCK_STATUS;
declare const index_BLOCK_STATUS: typeof BLOCK_STATUS;
type index_BLOCK_TAG = BLOCK_TAG;
type index_CALL_TYPE = CALL_TYPE;
type index_CHAIN_ID = CHAIN_ID;
type index_Call = Call;
type index_CallObject = CallObject;
type index_ChainId = ChainId;
declare const index_ETHEREUM_CHAIN_PREFIX: typeof ETHEREUM_CHAIN_PREFIX;
type index_ETH_ADDRESS = ETH_ADDRESS;
type index_ETH_CALL = ETH_CALL;
type index_EVMFunction = EVMFunction;
type index_Encodable = Encodable;
type index_EncodableArray = EncodableArray;
type index_EncodablePrimitive = EncodablePrimitive;
type index_EncodableTuple = EncodableTuple;
type index_EthereumChain = EthereumChain;
type index_EthereumProvider = EthereumProvider;
type index_GAS = GAS;
type index_INTERNAL_CALL = INTERNAL_CALL;
type index_LOG_ENTRY = LOG_ENTRY;
type index_LOW_LEVEL_CALL = LOW_LEVEL_CALL;
type index_MulticallElement = MulticallElement;
type index_MulticallProps = MulticallProps;
type index_NONCE = NONCE;
type index_ParameterDescription = ParameterDescription;
type index_SIGNATURE = SIGNATURE;
declare const index_STARKNET_CHAIN_PREFIX: typeof STARKNET_CHAIN_PREFIX;
type index_STATE_CHANGING_CALL = STATE_CHANGING_CALL;
type index_STORAGE_KEY = STORAGE_KEY;
type index_StarknetChain = StarknetChain;
type index_TX = TX;
type index_TXN_HASH = TXN_HASH;
type index_TX_RECEIPT = TX_RECEIPT;
type index_TX_REQUEST = TX_REQUEST;
type index_TX_STATUS = TX_STATUS;
declare const index_TX_STATUS: typeof TX_STATUS;
type index_TX_TYPE = TX_TYPE;
declare const index_TX_TYPE: typeof TX_TYPE;
type index_UINT128 = UINT128;
type index_UINT256 = UINT256;
type index_VIEW_CALL = VIEW_CALL;
declare namespace index {
  export { type index_BLOCK as BLOCK, type index_BLOCK_HASH as BLOCK_HASH, type index_BLOCK_NUMBER as BLOCK_NUMBER, type index_BLOCK_RECEIPTS as BLOCK_RECEIPTS, index_BLOCK_STATUS as BLOCK_STATUS, type index_BLOCK_TAG as BLOCK_TAG, type index_CALL_TYPE as CALL_TYPE, type index_CHAIN_ID as CHAIN_ID, type index_Call as Call, type index_CallObject as CallObject, type index_ChainId as ChainId, index_ETHEREUM_CHAIN_PREFIX as ETHEREUM_CHAIN_PREFIX, type index_ETH_ADDRESS as ETH_ADDRESS, type index_ETH_CALL as ETH_CALL, type index_EVMFunction as EVMFunction, type index_Encodable as Encodable, type index_EncodableArray as EncodableArray, type index_EncodablePrimitive as EncodablePrimitive, type index_EncodableTuple as EncodableTuple, type index_EthereumChain as EthereumChain, type index_EthereumProvider as EthereumProvider, type index_GAS as GAS, type index_INTERNAL_CALL as INTERNAL_CALL, type index_LOG_ENTRY as LOG_ENTRY, type index_LOW_LEVEL_CALL as LOW_LEVEL_CALL, type index_MulticallElement as MulticallElement, type index_MulticallProps as MulticallProps, type index_NONCE as NONCE, type index_ParameterDescription as ParameterDescription, type index_SIGNATURE as SIGNATURE, index_STARKNET_CHAIN_PREFIX as STARKNET_CHAIN_PREFIX, type index_STATE_CHANGING_CALL as STATE_CHANGING_CALL, type index_STORAGE_KEY as STORAGE_KEY, type index_StarknetChain as StarknetChain, type index_TX as TX, type index_TXN_HASH as TXN_HASH, type index_TX_RECEIPT as TX_RECEIPT, type index_TX_REQUEST as TX_REQUEST, index_TX_STATUS as TX_STATUS, index_TX_TYPE as TX_TYPE, type index_UINT128 as UINT128, type index_UINT256 as UINT256, type index_VIEW_CALL as VIEW_CALL };
}

declare function prepareMulticallCalldata(calls: Call[]): string;

declare function parseSignature(functionSignature: string): EVMFunction;
declare function generateFullSignature(functionDescription: EVMFunction): string;
declare function generateCanonicalSignature(functionDescription: EVMFunction): string;
declare function encodeMethod(keccak256: (message: Uint8Array) => Promise<bigint>, functionDescription: EVMFunction, parameters: EncodableArray): Promise<Uint8Array>;
declare function encodeMethod(keccak256: (message: Uint8Array) => Promise<bigint>, functionSignature: string, parameters: EncodableArray): Promise<Uint8Array>;
declare function encodeMethod(functionSelector: number, parameterDescriptions: ReadonlyArray<ParameterDescription>, parameters: EncodableArray): Uint8Array;
declare function encodeParameters(descriptions: ReadonlyArray<ParameterDescription>, parameters: EncodableArray): Uint8Array;

declare function getStarknetAddress(EthAddress: string, nodeUrl: string, rosettanetAddress: string): Promise<string>;

interface Request extends RequestFn {
    (request: {
        method: string;
        params?: Array<unknown>;
    }): Promise<any>;
}
interface EthereumWindowObject {
    request: Request;
    on: WalletEventListener;
    off: WalletEventListener;
    id: string;
    name: string;
    icon: string;
    version: '1.0.0';
}
declare function requestAccounts(ewo: EthereumWindowObject): Promise<string[]>;
declare function watchAsset(ewo: EthereumWindowObject, asset: WatchAssetParameters): Promise<boolean>;
declare function requestChainId(ewo: EthereumWindowObject): Promise<string>;
declare function sendTransaction(ewo: EthereumWindowObject, tx: TX_REQUEST): Promise<string>;
declare function switchRosettanetChain(ewo: EthereumWindowObject, chainId: ChainId$1): Promise<string>;
declare function getPermissions(ewo: EthereumWindowObject): Promise<Permission[]>;
declare function personalSign(ewo: EthereumWindowObject, message: string, address: string): Promise<string>;
declare function accounts(ewo: EthereumWindowObject): Promise<string[]>;
declare function clientVersion(ewo: EthereumWindowObject): Promise<string>;
declare function getBlockNumber(ewo: EthereumWindowObject): Promise<string>;
declare function call(ewo: EthereumWindowObject, tx: TX_REQUEST): Promise<string>;
declare function estimateGas(ewo: EthereumWindowObject, tx: TX_REQUEST): Promise<string>;
declare function gasPrice(ewo: EthereumWindowObject): Promise<string>;
declare function getBalance(ewo: EthereumWindowObject, address: string, block?: BLOCK_HASH | BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
declare function getBlockByHash(ewo: EthereumWindowObject, blockHash: BLOCK_HASH, hydratedTx?: boolean): Promise<string>;
declare function getBlockByNumber(ewo: EthereumWindowObject, blockNumber: BLOCK_NUMBER | BLOCK_TAG, hydratedTx?: boolean): Promise<string>;
declare function getBlockTransactionCountByHash(ewo: EthereumWindowObject, blockHash: BLOCK_HASH): Promise<string>;
declare function getBlockTransactionCountByNumber(ewo: EthereumWindowObject, blockNumber: BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
declare function getCode(ewo: EthereumWindowObject, address: string, block?: BLOCK_HASH | BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
declare function getTransactionHashByBlockHashAndIndex(ewo: EthereumWindowObject, blockHash: BLOCK_HASH, index: string): Promise<string>;
declare function getTransactionHashByBlockNumberAndIndex(ewo: EthereumWindowObject, blockNumber: BLOCK_NUMBER | BLOCK_TAG, index: string): Promise<string>;
declare function getTransactionByHash(ewo: EthereumWindowObject, txHash: TXN_HASH): Promise<string>;
declare function getTransactionCount(ewo: EthereumWindowObject, address: string, block?: BLOCK_HASH | BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
declare function getTransactionReceipt(ewo: EthereumWindowObject, txHash: TXN_HASH): Promise<string>;
declare function syncing(ewo: EthereumWindowObject): Promise<string>;
/**
 * Sign typed data using the wallet.
 * @param ewo wallet window object to request the signature.
 * @param message The typed data to sign.
 * @param address The wallet address to sign.
 * @returns Signatures as strings.
 */
declare function signMessage(ewo: EthereumWindowObject, message: TypedData, address: string): Promise<string>;

type rosettanetConnect_EthereumWindowObject = EthereumWindowObject;
declare const rosettanetConnect_accounts: typeof accounts;
declare const rosettanetConnect_call: typeof call;
declare const rosettanetConnect_clientVersion: typeof clientVersion;
declare const rosettanetConnect_estimateGas: typeof estimateGas;
declare const rosettanetConnect_gasPrice: typeof gasPrice;
declare const rosettanetConnect_getBalance: typeof getBalance;
declare const rosettanetConnect_getBlockByHash: typeof getBlockByHash;
declare const rosettanetConnect_getBlockByNumber: typeof getBlockByNumber;
declare const rosettanetConnect_getBlockNumber: typeof getBlockNumber;
declare const rosettanetConnect_getBlockTransactionCountByHash: typeof getBlockTransactionCountByHash;
declare const rosettanetConnect_getBlockTransactionCountByNumber: typeof getBlockTransactionCountByNumber;
declare const rosettanetConnect_getCode: typeof getCode;
declare const rosettanetConnect_getPermissions: typeof getPermissions;
declare const rosettanetConnect_getTransactionByHash: typeof getTransactionByHash;
declare const rosettanetConnect_getTransactionCount: typeof getTransactionCount;
declare const rosettanetConnect_getTransactionHashByBlockHashAndIndex: typeof getTransactionHashByBlockHashAndIndex;
declare const rosettanetConnect_getTransactionHashByBlockNumberAndIndex: typeof getTransactionHashByBlockNumberAndIndex;
declare const rosettanetConnect_getTransactionReceipt: typeof getTransactionReceipt;
declare const rosettanetConnect_personalSign: typeof personalSign;
declare const rosettanetConnect_requestAccounts: typeof requestAccounts;
declare const rosettanetConnect_requestChainId: typeof requestChainId;
declare const rosettanetConnect_sendTransaction: typeof sendTransaction;
declare const rosettanetConnect_signMessage: typeof signMessage;
declare const rosettanetConnect_switchRosettanetChain: typeof switchRosettanetChain;
declare const rosettanetConnect_syncing: typeof syncing;
declare const rosettanetConnect_watchAsset: typeof watchAsset;
declare namespace rosettanetConnect {
  export { type rosettanetConnect_EthereumWindowObject as EthereumWindowObject, rosettanetConnect_accounts as accounts, rosettanetConnect_call as call, rosettanetConnect_clientVersion as clientVersion, rosettanetConnect_estimateGas as estimateGas, rosettanetConnect_gasPrice as gasPrice, rosettanetConnect_getBalance as getBalance, rosettanetConnect_getBlockByHash as getBlockByHash, rosettanetConnect_getBlockByNumber as getBlockByNumber, rosettanetConnect_getBlockNumber as getBlockNumber, rosettanetConnect_getBlockTransactionCountByHash as getBlockTransactionCountByHash, rosettanetConnect_getBlockTransactionCountByNumber as getBlockTransactionCountByNumber, rosettanetConnect_getCode as getCode, rosettanetConnect_getPermissions as getPermissions, rosettanetConnect_getTransactionByHash as getTransactionByHash, rosettanetConnect_getTransactionCount as getTransactionCount, rosettanetConnect_getTransactionHashByBlockHashAndIndex as getTransactionHashByBlockHashAndIndex, rosettanetConnect_getTransactionHashByBlockNumberAndIndex as getTransactionHashByBlockNumberAndIndex, rosettanetConnect_getTransactionReceipt as getTransactionReceipt, rosettanetConnect_personalSign as personalSign, rosettanetConnect_requestAccounts as requestAccounts, rosettanetConnect_requestChainId as requestChainId, rosettanetConnect_sendTransaction as sendTransaction, rosettanetConnect_signMessage as signMessage, rosettanetConnect_switchRosettanetChain as switchRosettanetChain, rosettanetConnect_syncing as syncing, rosettanetConnect_watchAsset as watchAsset };
}

declare enum RosettanetChainId {
    MAIN = "0x52535453"
}

declare class RosettanetAccount extends Account implements AccountInterface {
    walletProvider: EthereumWindowObject;
    constructor(providerOrOptions: ProviderOptions | ProviderInterface, walletProvider: EthereumWindowObject, cairoVersion?: CairoVersion, address?: string);
    /**
     * Send transaction to the wallet.
     * @param params Ethereum transaction object.
     * @returns Transaction hash.
     */
    sendTransactionRosettanet(params: TX_REQUEST): Promise<string>;
    /**
     * Request the current chain ID from the wallet.
     * @returns The current Wallet Chain ID.
     */
    chainIdRosettanet(): Promise<string>;
    /**
     * Sign typed data using the wallet. Uses personal_sign method.
     * @param message The typed data to sign.
     * @param address The wallet address to sign.
     * @returns Signatures as strings.
     */
    personalSignRosettanet(message: string, address: string): Promise<string>;
    /**
     * Request connected accounts
     * @returns connected accounts addresses
     */
    accountsRosettanet(): Promise<string[]>;
    /**
     * Request latest block number in Starknet
     * @returns latest block number in hexadecimal format
     */
    blockNumberRosettanet(): Promise<string>;
    /**
     * Call request.
     * @param tx Ethereum transaction object.
     * @returns Answer from called contract.
     */
    callRosettanet(tx: TX_REQUEST): Promise<string>;
    /**
     * Estimated gas fee for the transaction.
     * @param tx Ethereum transaction object.
     * @returns Estimated gas amount.
     */
    estimateGasRosettanet(tx: TX_REQUEST): Promise<string>;
    /**
     * Latest gas price in network.
     * @returns Latest gas price.
     */
    gasPriceRosettanet(): Promise<string>;
    /**
     * STRK balance of given address.
     * @param address Address to check balance.
     * @param block Block number or hash. (optional)
     * @returns STRK balance.
     */
    getBalanceRosettanet(address: string, block?: BLOCK_HASH | BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
    /**
     * Block by given block hash.
     * @param blockHash Block hash.
     * @param hydratedTx Hydrated transactions (optional)
     * @returns Block by given block hash.
     */
    getBlockByHashRosettanet(blockHash: BLOCK_HASH, hydratedTx?: boolean): Promise<string>;
    /**
     * Block by given block number.
     * @param blockNumber Block number or block tag.
     * @param hydratedTx Hydrated transactions (optional)
     * @returns Block by given block number.
     */
    getBlockByNumberRosettanet(blockNumber: BLOCK_NUMBER | BLOCK_TAG, hydratedTx?: boolean): Promise<string>;
    /**
     * Transaction count of given block hash.
     * @param blockHash Block hash.
     * @returns Transaction count of given block hash.
     */
    getBlockTransactionCountByHashRosettanet(blockHash: BLOCK_HASH): Promise<string>;
    /**
     * Transaction count of given block number.
     * @param blockNumber Block number or block tag..
     * @returns Transaction count of given block number.
     */
    getBlockTransactionCountByNumberRosettanet(blockNumber: BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
    getCodeRosettanet(address: string, block?: BLOCK_HASH | BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
    getTransactionHashByBlockHashAndIndexRosettanet(blockHash: BLOCK_HASH, index: string): Promise<string>;
    getTransactionHashByBlockNumberAndIndexRosettanet(blockNumber: BLOCK_NUMBER | BLOCK_TAG, index: string): Promise<string>;
    getTransactionByHashRosettanet(txHash: TXN_HASH): Promise<string>;
    /**
     * Transaction count of given address.
     * @param address address.
     * @returns Transaction count of given address.
     */
    getTransactionCountRosettanet(address: string, block?: BLOCK_HASH | BLOCK_NUMBER | BLOCK_TAG): Promise<string>;
    /**
     * Transaction receipt of given transaction hash.
     * @param txHash address.
     * @returns Transaction receipt of given transaction hash.
     */
    getTransactionReceiptRosettanet(txHash: TXN_HASH): Promise<string>;
    requestAccounts(): Promise<string[]>;
    /**
     * Request Permission for wallet account
     * @returns allowed accounts addresses
     */
    getPermissions(): Promise<"accounts"[]>;
    switchStarknetChain(chainId: RosettanetChainId): Promise<string>;
    /**
     * Request adding ERC20 Token to Wallet List
     * @param asset WatchAssetParameters
     * @returns boolean
     */
    watchAsset(asset: WatchAssetParameters): Promise<boolean>;
    declare(): Promise<{
        transaction_hash: string;
        class_hash: string;
    }>;
    deploy(): Promise<{
        transaction_hash: string;
        contract_address: string[];
    }>;
    /**
     * Sign typed data using the wallet. Uses eth_signTypedData_v4 method.
     * @param message The typed data to sign.
     * @returns Signature as strings.
     */
    signMessage(message: TypedData): Promise<ArraySignatureType>;
    execute(calls: Call$1[]): Promise<{
        transaction_hash: string;
    }>;
    static connect(provider: ProviderInterface, walletProvider: EthereumWindowObject, cairoVersion?: CairoVersion): Promise<RosettanetAccount>;
    static connectSilent(provider: ProviderInterface, walletProvider: EthereumWindowObject, cairoVersion?: CairoVersion): Promise<RosettanetAccount>;
}

declare const StarknetWalletApi = "starknet:walletApi";
type StarknetWalletApiVersion = '1.0.0';
type StarknetWalletRequestFeature = {
    readonly [StarknetWalletApi]: {
        readonly version: StarknetWalletApiVersion;
        readonly request: RequestFn;
        readonly walletVersion: string;
    };
};
type StarknetFeatures = StarknetWalletRequestFeature & StandardConnectFeature & StandardDisconnectFeature & StandardEventsFeature;
type EthereumWalletWithStarknetFeatures = WalletWithFeatures<StarknetFeatures>;
declare function isEVMWallet(wallet: Wallet): wallet is EthereumWalletWithStarknetFeatures;

/**
 * Implementation of the Wallet Standard for Ethereum/EVM wallets
 */
declare class EthereumInjectedWallet implements EthereumWalletWithStarknetFeatures {
    #private;
    private readonly injected;
    constructor(injected: StarknetWindowObject);
    get version(): "1.0.0";
    get name(): string;
    get icon(): Wallet["icon"];
    get features(): StarknetFeatures;
    get chains(): EthereumChain[];
    get accounts(): WalletAccount[];
}

declare function EvmWalletsWithStarknetFeatures(): Promise<EthereumInjectedWallet[]>;
declare function isEthereumWindowObject(wallet: unknown): wallet is EthereumProvider;

export { EthereumInjectedWallet, type EthereumWalletWithStarknetFeatures, EvmWalletsWithStarknetFeatures, RosettanetAccount, type StarknetFeatures, StarknetWalletApi, type StarknetWalletApiVersion, type StarknetWalletRequestFeature, encodeMethod, encodeParameters, generateCanonicalSignature, generateFullSignature, getStarknetAddress, isEVMWallet, isEthereumWindowObject, parseSignature, prepareMulticallCalldata, rosettanetConnect as rosettanetWallet, index as types };
